@@ -2,7 +2,6 @@
 from distutils and setuptools.
 """
 
-
 from __future__ import annotations
 
 import argparse
@@ -41,7 +40,6 @@ from .command import (
     install_lib,
     install_scripts,
     sdist,
-    test,
 )
 from .constants import (
     CMAKE_DEFAULT_EXECUTABLE,
@@ -170,7 +168,7 @@ def _capture_output() -> Generator[list[io.StringIO | str], None, None]:
 
 
 def _parse_setuptools_arguments(
-    setup_attrs: Mapping[str, Any]
+    setup_attrs: Mapping[str, Any],
 ) -> tuple[bool, bool, list[str], bool, bool, bool, str, bool]:
     """This function instantiates a Distribution object and
     parses the command line arguments.
@@ -245,7 +243,7 @@ def _parse_setuptools_arguments(
         names = ", ".join(plat_names)
         msg = f"--plat-name is ambiguous: {names}"
         raise SKBuildError(msg)
-    plat_name = list(plat_names)[0]
+    plat_name = next(iter(plat_names))
 
     build_ext_cmd = dist.get_command_obj("build_ext")
     build_ext_inplace: bool = getattr(build_ext_cmd, "inplace", False)
@@ -342,7 +340,6 @@ def _should_run_cmake(commands: Sequence[str], cmake_with_sdist: bool) -> bool:
         "bdist_rpm",
         "bdist_wininst",
         "bdist_wheel",
-        "test",
     }
 
     if expected_commands & given_commands:
@@ -370,7 +367,10 @@ def _load_cmake_spec() -> Any:
 
 
 def get_default_include_package_data() -> bool:
-    # Include package data if pyproject.toml contains the project or tool.setuptools table.
+    """
+    Include package data if pyproject.toml contains the project or
+    tool.setuptools table.
+    """
     # https://setuptools.pypa.io/en/latest/history.html#id255
     # https://github.com/pypa/setuptools/pull/3067
     pyproject_file = os.path.join(os.getcwd(), "pyproject.toml")
@@ -382,7 +382,6 @@ def get_default_include_package_data() -> bool:
         return False
 
 
-# pylint:disable=too-many-locals, too-many-branches
 def setup(
     *,
     cmake_args: Sequence[str] = (),
@@ -394,7 +393,7 @@ def setup(
     cmake_process_manifest_hook: Callable[[list[str]], list[str]] | None = None,
     cmake_install_target: str = "install",
     **kw: Any,
-) -> None:
+) -> upstream_Distribution:
     """This function wraps setup() so that we can run cmake, make,
     CMake build, then proceed as usual with setuptools, appending the
     CMake-generated output as necessary.
@@ -440,7 +439,6 @@ def setup(
     cmdclass["generate_source_manifest"] = cmdclass.get(
         "generate_source_manifest", generate_source_manifest.generate_source_manifest
     )
-    cmdclass["test"] = cmdclass.get("test", test.test)
     kw["cmdclass"] = cmdclass
 
     # Extract setup keywords specific to scikit-build and remove them from kw.
@@ -512,7 +510,7 @@ def setup(
             print(flush=True)
         return setuptools.setup(**kw)
 
-    developer_mode = "develop" in commands or "test" in commands or build_ext_inplace
+    developer_mode = "develop" in commands or build_ext_inplace
 
     packages = kw.get("packages", [])
     package_dir = kw.get("package_dir", {})
@@ -623,9 +621,8 @@ def setup(
                 # taking care of it below.
 
                 # A local "cmake" folder can be imported by mistake, keep going if it is
-                from cmake import (
-                    CMAKE_BIN_DIR,  # pylint: disable=import-outside-toplevel
-                )
+                # pylint: disable-next=import-outside-toplevel
+                from cmake import CMAKE_BIN_DIR
 
                 for executable_name in ("cmake", "cpack", "ctest"):
                     executable = os.path.join(CMAKE_BIN_DIR, executable_name)
@@ -633,7 +630,8 @@ def setup(
                         executable += ".exe"
                     st = os.stat(executable)
                     permissions = st.st_mode | stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH
-                    os.chmod(executable, permissions)
+                    with contextlib.suppress(PermissionError):
+                        os.chmod(executable, permissions)
                 cmake_executable = os.path.join(CMAKE_BIN_DIR, "cmake")
                 break
 
@@ -771,7 +769,7 @@ def setup(
 
     # Adapted from espdev/ITKPythonInstaller/setup.py.in
     class BinaryDistribution(upstream_Distribution):  # pylint: disable=missing-class-docstring
-        def has_ext_modules(self) -> bool:  # pylint: disable=no-self-use,missing-function-docstring
+        def has_ext_modules(self) -> bool:  # pylint: disable=missing-function-docstring
             return has_cmakelists
 
     kw["distclass"] = BinaryDistribution
